# Glk

The Glk specification was written by Andrew Plotkin as an attempt to define a standard input and output interface for general use in IF related projects. Windows Git uses my (David Kinder) implementation of Glk, called Windows Glk. Windows Glk is a complete implementation of all the features described in version 0.7.4 of the Glk specification.

The complete Windows Glk package, including developer information, can be downloaded from the IF Archive's Glk implementations page.

More information on Glk is available from the Glk web page: http://www.eblong.com/zarf/glk/